@@ -80,8 +80,7 @@ class MyWhatify:
                 print(e)
         return source_id
 
-    def preparing_data_set(self, source_id, data_set_name, sample_id=None, retype_columns=None, target='class',
-                           problem_type=ProblemType.CLASSIFICATION, wait=True):
+    def preparing_data_set(self, source_id, data_set_name, sample_id=None, retype_columns=None, target='class', problem_type=ProblemType.CLASSIFICATION, wait=True):
         if sample_id is None:
             sample_id = ['car_id']
         if retype_columns is None:
